@@ -33,40 +33,6 @@ xpath /pom:project/pom:properties/pom:maven.compiler.source/text()
 EOF
 }
 
-function jdk_version() {
-  local result
-  local java_cmd
-  if [[ -n $(type -p java) ]]
-  then
-    java_cmd=java
-  elif [[ (-n "$JAVA_HOME") && (-x "$JAVA_HOME/bin/java") ]]
-  then
-    java_cmd="$JAVA_HOME/bin/java"
-  fi
-  local IFS=$'\n'
-  # remove \r for Cygwin
-  local lines=$("$java_cmd" -Xms32M -Xmx32M -version 2>&1 | tr '\r' '\n')
-  if [[ -z $java_cmd ]]
-  then
-    result=no_java
-  else
-    for line in $lines; do
-      if [[ (-z $result) && ($line = *"version \""*) ]]
-      then
-        local ver=$(echo $line | sed -e 's/.*version "\(.*\)"\(.*\)/\1/; 1q')
-        # on macOS, sed doesn't support '?'
-        if [[ $ver = "1."* ]]
-        then
-          result=$(echo $ver | sed -e 's/1\.\([0-9]*\)\(.*\)/\1/; 1q')
-        else
-          result=$(echo $ver | sed -e 's/\([0-9]*\)\(.*\)/\1/; 1q')
-        fi
-      fi
-    done
-  fi
-  echo "$result"
-}
-
 function getProjectVersionFromPom {
     cat << EOF | xmllint --noent --shell pom.xml | grep content | cut -f2 -d=
 setns pom=http://maven.apache.org/POM/4.0.0
@@ -174,22 +140,6 @@ function generate_signatures_from_release {
 
     echo "========================================================================
 
-    The signatures for the source release artefacts:
-
-    " > /tmp/release-$version-sigs.txt
-
-    pushd target/dist > /dev/null
-    for i in apache-wicket*{zip,tar.gz}
-    do
-        echo "Signature for $i:
-
-    $(cat $i.asc)
-    " >> /tmp/release-$version-sigs.txt
-    done
-    popd > /dev/null
-
-        echo "========================================================================
-
     CHANGELOG for $version:
     " >> /tmp/release-$version-sigs.txt
 
@@ -252,8 +202,7 @@ more. You can find more about Apache Wicket at https://wicket.apache.org
 
 This release marks another minor release of Wicket $major_version. We
 use semantic versioning for the development of Wicket, and as such no
-API breaks are present breaks are present in this release compared to
-$major_version.0.0.
+API breaks are present in this release compared to $major_version.0.0.
 
 <OPTIONAL> New and noteworthy
 <OPTIONAL> ------------------
@@ -314,7 +263,7 @@ git add wicket-$version-released.md
 
 # the branch on which the code base lives for this version (master is
 # always current development version)
-GIT_BRANCH=wicket-7.x
+GIT_BRANCH=master
 
 JAVA_VERSION=$(getJavaVersionFromPom)
 
@@ -412,8 +361,8 @@ then
 fi
 
 if [ ! -z "$milestone_version" ] ; then
-    next_version="$major_version.0.0-SNAPSHOT"
-    previous_version="$major_version.0.0-SNAPSHOT"
+    next_version="$major_version.0.0-M$(expr $milestone_version + 1)-SNAPSHOT"
+    previous_version="$major_version.0.0-M$milestone_version-SNAPSHOT"
 else
     next_version="$major_version.$(expr $minor_version + 1).0-SNAPSHOT"
     previous_minor_version=$(expr $minor_version - 1)
@@ -534,21 +483,14 @@ echo "Clean all projects"
 mvn -q clean -Pall
 
 # package and assemble the release
-## if we are using a JDK greater than 10, we add jdk11 profile
-JDK11_PROFILE=""
-
-if [ "$(jdk_version)" -gt 10 ] ; then
-    JDK11_PROFILE=",jdk11"
-fi
-
 echo "Prepare the release"
-mvn --batch-mode release:prepare -X -l $log -DpreparationGoals="clean" -Dtag=$tag -Papache-release,release$JDK11_PROFILE
+mvn --batch-mode release:prepare -X -l $log -DpreparationGoals="clean" -Dtag=$tag -Papache-release,release
 if [ $? -ne 0 ] ; then
     fail "ERROR: mvn release:prepare was not successful"
 fi
 
 echo "Performing the release using Maven"
-mvn -Dgpg.passphrase="$passphrase" -ff -l $log release:perform -DlocalCheckout=true -Dtag=$tag -Papache-release,release$JDK11_PROFILE
+mvn -Dgpg.passphrase="$passphrase" -ff -l $log release:perform -DlocalCheckout=true -Dtag=$tag -Papache-release,release
 if [ $? -ne 0 ] ; then
     fail "ERROR: mvn release:perform was not successful"
 fi
@@ -654,6 +596,9 @@ Use the release-announce.txt as a starter for the release announcement:
 
     cat release-announce.txt | pbcopy
 
+A Markdown file called wicket-$version-released.md has been also generated.
+You can use it to update the site with the release announcement.
+
 To promote the release after a successful vote, run:
 
     $ ./promote-$version.sh
